<?php

namespace EventPortal\Domain\Comment\Models;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Model;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Database\Eloquent\Relations\MorphTo;

class Comment extends Model
{
    public const KEY = 'comment';

    /** @var array<string> */
    protected $fillable = [
        'admin_id',
        'comment',
        'reason',
    ];

    protected $casts = [
        'reason' => 'array',
    ];

    protected $appends = [
        'checked_by',
        'formatted_created_at',
    ];

    public $incrementing = true;

    public function commentable(): MorphTo
    {
        return $this->morphTo();
    }

    public function admin(): HasOne
    {
        return $this->hasOne(Admin::class, 'id', 'admin_id');
    }

    public function getCheckedByAttribute(): string
    {
        $admin = $this->admin()->first();

        if ($admin === null) {
            return '';
        }

        $user = $admin->user()->first();

        if ($user === null) {
            return '';
        }

        return $user->full_name;
    }

    public function getFormattedCreatedAtAttribute(): string
    {
        return $this->created_at->format('dS F Y');
    }
}
