<?php

namespace EventPortal\Domain\Event\ValueObjects;

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Enums\InertiaMethod;
use Illuminate\Support\Str;

class UnableToAttendSection
{
    /** @var string */
    public $title;

    /** @var string */
    public $description;

    /** @var \EventPortal\Contracts\Event */
    private $event;

    /** @var null|Form */
    private $form;

    /** @var string */
    private $status;

    public static function make(): self
    {
        return new self();
    }

    public function forEventDelegate(EventDelegate $eventDelegate): self
    {
        $this->event = $eventDelegate->event;
        $this->form = Form::forEvent($this->event)->decline()->first();

        $this->title = 'Unable to attend?';
        $this->setDescription($this->event->name);
        $this->status = $eventDelegate->status;

        return $this;
    }

    public function shouldShow(): bool
    {
        return $this->form !== null && in_array($this->status, [
            'invited',
            'registering',
            'declining',
        ]);
    }

    private function setDescription(string $eventName): void
    {
        $this->description = (string) Str::of("We hope that you will be joining us for {$eventName}.")
            ->append(' However, if you will not be able to attend please let us know as soon as possible.')
            ->append(' By informing us early you allow us to offer spaces to other colleagues who may like to attend.');
    }

    public function get(): array
    {
        return [
            'title' => $this->title,
            'description' => $this->description,
            'button' => Button::make('Decline invite')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('delegate.form.index', [
                    'event' => $this->event->slug,
                    'form' => $this->form->slug,
                ]),
        ];
    }
}
