<?php

namespace EventPortal\Tests\Unit\Util;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\User\Models\User;
use EventPortal\Domain\Util\Notification\Facades\Notification;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Carbon;
use Spatie\Snapshots\MatchesSnapshots;

class NotificationTest extends TestCase
{
    use MatchesSnapshots, RefreshDatabase;

    /** @test */
    public function a_notification_can_be_generated_from_config()
    {
        $notification = Notification::make('admin.created');

        $this->assertMatchesJsonSnapshot($notification->toArray());
    }

    /** @test **/
    public function a_notification_can_have_a_single_recipient()
    {
        $notification = Notification::make('admin.created');
        $recipient = factory(User::class)->state('snapshot')->create();

        $notification->to($recipient);

        $this->assertMatchesSnapshot($notification->toArray());
    }

    /** @test **/
    public function a_notification_can_have_a_multiple_recipients()
    {
        $notification = Notification::make('admin.created');
        $recipients = factory(User::class, 25)->state('snapshot')->create();

        $notification->to($recipients);

        $this->assertMatchesJsonSnapshot($notification->toArray());
    }

    /** @test */
    public function a_notification_can_be_generated_for_an_event()
    {
        $event = factory(Event::class)->state('snapshot')->create();

        $notification = Notification::make('event.invite')
            ->event($event);

        $this->assertMatchesJsonSnapshot($notification->toArray());
    }

    /** @test **/
    public function the_configured_values_can_be_overridden()
    {
        $notification = Notification::make('admin.created')
            ->subject('New subject');

        $this->assertMatchesJsonSnapshot($notification->toArray());
    }

    /** @test **/
    public function the_reply_to_address_can_be_overridden()
    {
        $notification = Notification::make('override.sender')
            ->replyTo('test@example.com');

        $this->assertMatchesJsonSnapshot($notification->toArray());
    }

    public function setUp(): void
    {
        parent::setUp();
        Carbon::setTestNow('3rd September 2020 12:57:00');
    }
}
